pdf2svg: PDF to SVG convertor
=============================

Description
-----------

pdf2svg is a tiny command-line utility using Cairo and Poppler to convert PDF
documents into SVG files. Multi-page PDF can be split up to one SVG per page by
passing a file naming specification.

License
-------

GPL

Upstream Contact
----------------

http://cityinthesky.co.uk/opensource/pdf2svg/
